[Author Prev][Author Next][Thread Prev][Thread Next][Author Index][Thread Index]

[minion-cvs] Spelling fixes



Update of /home/minion/cvsroot/src/minion/lib/mixminion/directory
In directory moria.mit.edu:/tmp/cvs-serv8484/lib/mixminion/directory

Modified Files:
	Directory.py ServerInbox.py ServerList.py 
Log Message:
Spelling fixes

Index: Directory.py
===================================================================
RCS file: /home/minion/cvsroot/src/minion/lib/mixminion/directory/Directory.py,v
retrieving revision 1.11
retrieving revision 1.12
diff -u -d -r1.11 -r1.12
--- Directory.py	6 Jun 2003 06:08:39 -0000	1.11
+++ Directory.py	13 Jul 2003 03:45:34 -0000	1.12
@@ -18,7 +18,7 @@
      formatBase64, writePickled, readPickled
 
 class Directory:
-    """Wraper class for directory filestores.
+    """Wrapper class for directory filestores.
 
        Currently, a directory server keeps two filestores: an 'ServerInbox'
        that contains servers which have been uploaded but not yet inserted
@@ -223,7 +223,7 @@
     pass
 
 class IDCache:
-    """Cache to hold a set of nickname->identitye key mappings"""
+    """Cache to hold a set of nickname->identity key mappings"""
     ##Fields:
     # cache: map from lowercased nickname to ID fingerprint.
     # location: filename to hold pickled cache.

Index: ServerInbox.py
===================================================================
RCS file: /home/minion/cvsroot/src/minion/lib/mixminion/directory/ServerInbox.py,v
retrieving revision 1.10
retrieving revision 1.11
diff -u -d -r1.10 -r1.11
--- ServerInbox.py	11 Jul 2003 03:06:57 -0000	1.10
+++ ServerInbox.py	13 Jul 2003 03:45:34 -0000	1.11
@@ -48,7 +48,7 @@
 
            text -- a string containing a new server descriptor.
            source -- a (human readable) string describing the source
-               of the descriptor, used in error meessages.
+               of the descriptor, used in error messages.
         
            """
         try:

Index: ServerList.py
===================================================================
RCS file: /home/minion/cvsroot/src/minion/lib/mixminion/directory/ServerList.py,v
retrieving revision 1.34
retrieving revision 1.35
diff -u -d -r1.34 -r1.35
--- ServerList.py	10 Jul 2003 20:01:31 -0000	1.34
+++ ServerList.py	13 Jul 2003 03:45:34 -0000	1.35
@@ -251,7 +251,7 @@
                 includedByNickname.setdefault(nickname, []).append((s, fn))
 
             # Second, find all servers that are valid for part of the period,
             # and that aren't superceded for the whole period.
             timeRange = IntervalSet([(previousMidnight(startAt),
                                       endAt+extraTime)])
 
@@ -351,7 +351,7 @@
         return os.path.join(self.baseDir, "directory")
 
     def clean(self, now=None):
         """Remove all expired or superceded servers from the active directory.
         """
         # This algorithm is inefficient: O(N_descs * N_descs_per_nickname).
         # We're just going to ignore that.
@@ -370,7 +370,7 @@
                 servers = [ s for _, _, s  in servers ]
                 for idx in range(len(servers)):
                     if servers[idx].isSupersededBy(servers[idx+1:]):
-                        removed[fns[idx]] = "superceded"
+                        removed[fns[idx]] = "superseded"
 
             # Find all expired servers.
             for fn, s in self.servers.items():
@@ -251,7 +251,7 @@
 
             # Second, find all servers that are valid for part of the period,
-            # and that aren't superceded for the whole period.
+            # and that aren't superseded for the whole period.
             timeRange = IntervalSet([(previousMidnight(startAt),
                                       endAt+extraTime)])
@@ -351,7 +351,7 @@
 
     def clean(self, now=None):
-        """Remove all expired or superceded servers from the active directory.
+        """Remove all expired or superseded servers from the active directory.
         """
         # This algorithm is inefficient: O(N_descs * N_descs_per_nickname).